/* adc_display
 *  
 * Egyszerű mérés az ADC-vel: az A0 bemenetre adott
 * feszültséget mérjük az Arduino tápfeszültségéhez képest.
 * Az ADC által visszaadott viszonyszámot (0 - 1023)
 * megjelenítjük a Multifunkciós bővítőkártya hétszegmens
 * kijelzőjén. 
 * Az eredményt ellenőrzés gyanánt a soros porton is kiíratjuk.
 * A mérés és a soros porti kiíratás 1 másodpercenként történik (TASK1).
 * A multiplex kijelzés a mérési szünetekben folyamatosan történik (TASK2).
 */
 
/* Define shift register pins used for seven segment display */
#define LATCH_DIO 4
#define CLK_DIO 7
#define DATA_DIO 8

#define Pot1 A0

/* Segment byte maps for numbers 0 to 9 */
const byte SEGMENT_MAP[] = {0xC0, 0xF9, 0xA4, 0xB0, 0x99, 0x92, 0x82, 0xF8, 0X80, 0X90};
/* Byte maps to select digit 1 to 4 */
const byte SEGMENT_SELECT[] = {0xF1, 0xF2, 0xF4, 0xF8};
long nexttime;

void setup () {
  Serial.begin(115200);
  /* Set DIO pins to outputs */
  pinMode(LATCH_DIO, OUTPUT);
  pinMode(CLK_DIO, OUTPUT);
  pinMode(DATA_DIO, OUTPUT);
  nexttime = 1000 + millis();
}

/* Main program */
void loop() {
  int PotValue;
  if (millis() > nexttime) {          // TASK1 másodpercenként fut le
    PotValue = analogRead(Pot1);
    Serial.print("Potentiometer: ");
    Serial.println(PotValue);
    nexttime += 1000;
  }
  /* Mérési szünetekben pörgetjük a kijelzést (TASK2) */
  WriteNumberToSegment(0 , PotValue / 1000);
  WriteNumberToSegment(1 , (PotValue / 100) % 10);
  WriteNumberToSegment(2 , (PotValue / 10) % 10);
  WriteNumberToSegment(3 , PotValue % 10);
}

/* A soron következő számjegy megjelenítése */
void WriteNumberToSegment(byte Segment, byte Value) {
  digitalWrite(LATCH_DIO, LOW);
  shiftOut(DATA_DIO, CLK_DIO, MSBFIRST, SEGMENT_MAP[Value]);
  shiftOut(DATA_DIO, CLK_DIO, MSBFIRST, SEGMENT_SELECT[Segment] );
  digitalWrite(LATCH_DIO, HIGH);
}
